# Release notes for MUSE v1.2.2 (October 28, 2024)

These are the main changes in MUSE v1.2.2.

## Bug fixes

This release fixes several errors in calculations related to the utilization factor, minimum service factor and commodity prices. Interested readers can follow the discussions in the following pull requests:

- {github}`368`
- {github}`518`
- {github}`534`

Developers should pay particular attention to the latter two PRs, to avoid introducing similar mistakes in the future.
